diff --git a/sohstationviewer/view/channel_prefer_dialog.py b/sohstationviewer/view/channel_prefer_dialog.py
index 0e08d7f670b19bea22c206d759e55cafd1e0b774..a9d99ab2337b8f8d619cec0b7896d0639ac6c77e 100755
--- a/sohstationviewer/view/channel_prefer_dialog.py
+++ b/sohstationviewer/view/channel_prefer_dialog.py
@@ -46,7 +46,7 @@ class InputDialog(QDialog):
 
 
 class ChannelPreferDialog(OneWindowAtATimeDialog):
-    def __init__(self, parent, dir_names):
+    def __init__(self, parent, list_of_dir):
         """
         Dialog to create lists of preferred SOH channels that users want to
             select for plotting.
@@ -55,12 +55,12 @@ class ChannelPreferDialog(OneWindowAtATimeDialog):
 
         :param parent: QWidget/QMainWindow - widget that calls this plotting
             widget
         :param dir_names: str - absolute path to the folder that contains
             data
         """
         super(ChannelPreferDialog, self).__init__()
         self.parent = parent
-        self.dir_names = dir_names
+        self.list_of_dir = list_of_dir
         self.setWindowTitle("SOH Channel Preferences")
         self.setGeometry(100, 100, 1100, 800)
         main_layout = QtWidgets.QVBoxLayout()
@@ -90,7 +90,7 @@ class ChannelPreferDialog(OneWindowAtATimeDialog):
         """
         self.add_db_chan_btn: Union[QtWidgets.QPushButton, None] = None
         """
         scan_chan_btn: Button to scan through all channels from dir_names
             folder for the list of channels and data type to add
             to the current row
         """
@@ -394,7 +394,7 @@ class ChannelPreferDialog(OneWindowAtATimeDialog):
     @QtCore.Slot()
     def scan_channels(self):
         """
         Scan for all available channels in folder self.dir_names to add to
             preferred channel list.
         For RT130, all SOH channels are kept in a log file. It will be more
             reasonable to get channels from DB because the task of getting
@@ -406,7 +406,7 @@ class ChannelPreferDialog(OneWindowAtATimeDialog):
             data_type = 'RT130'
         else:
             try:
-                data_type = detect_data_type(self.dir_names)
+                data_type = detect_data_type(self.list_of_dir)
             except Exception as e:
                 QtWidgets.QMessageBox.warning(self, "Scan Channels", str(e))
                 return
@@ -428,9 +428,9 @@ class ChannelPreferDialog(OneWindowAtATimeDialog):
         else:
             self.scan_chan_btn.setEnabled(True)
             ret = read_mseed_channels(self.tracking_info_text_browser,
-                                      self.dir_names)
+                                      self.list_of_dir)
             if ret == ([], [], [], []):
-                msg = "No data can be read from " + ', '.join(self.dir_names)
+                msg = "No data can be read from " + ', '.join(self.list_of_dir)
                 return QtWidgets.QMessageBox.warning(self, "No data", msg)
 
             (soh_chan_ids, mass_pos_chan_ids,
@@ -55,12 +55,12 @@ class ChannelPreferDialog(OneWindowAtATimeDialog):
         :param parent: QWidget/QMainWindow - widget that calls this plotting
             widget
-        :param dir_names: str - absolute path to the folder that contains
+        :param list_of_dir: str - absolute path to the folder that contains
             data
         """
@@ -90,7 +90,7 @@ class ChannelPreferDialog(OneWindowAtATimeDialog):
         self.add_db_chan_btn: Union[QtWidgets.QPushButton, None] = None
         """
-        scan_chan_btn: Button to scan through all channels from dir_names
+        scan_chan_btn: Button to scan through all channels from list_of_dir
             folder for the list of channels and data type to add
             to the current row
@@ -394,7 +394,7 @@ class ChannelPreferDialog(OneWindowAtATimeDialog):
     def scan_channels(self):
         """
-        Scan for all available channels in folder self.dir_names to add to
+        Scan for all available channels in folder self.list_of_dir to add to
             preferred channel list.
         For RT130, all SOH channels are kept in a log file. It will be more